==> Smdn.Net.Pop3.Client-1.01.tar.bz2: Smdn.Net.Pop3.Client-1.01/Smdn.Net.Pop3.Client/Smdn.Net.Pop3.Client.Transaction.BuiltIn/CapaTransaction.cs <==
// 
// Author:
//       smdn <smdn@smdn.jp>
// 
// Copyright (c) 2008-2010 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;

using Smdn.Net.Pop3.Protocol.Client;

namespace Smdn.Net.Pop3.Client.Transaction.BuiltIn {
  internal sealed class CapaTransaction : PopTransactionBase<PopCommandResult<PopCapabilityList>> {
    public CapaTransaction(PopConnection connection)
      : base(connection)
    {
      IsResponseMultiline = true;
    }

    protected override ProcessTransactionDelegate Reset()
    {
      return ProcessCapa;
    }

    /*
     * RFC 2449 - POP3 Extension Mechanism
     * 
     * CAPA
     *    Arguments:
     *       none
     *    Restrictions:
     *       none
     *    Possible Responses:
     *        +OK -ERR
     */
    private void ProcessCapa()
    {
      SendCommand("CAPA", ProcessReceiveResponse);
    }

    protected override void OnFollowingResponseReceived(PopFollowingResponse following)
    {
      capabilities.Add(PopResponseConverter.FromCapa(following));

      base.OnFollowingResponseReceived(following);
    }

    protected override void OnTerminationResponse(PopTerminationResponse termination)
    {
      Finish(new PopCommandResult<PopCapabilityList>(capabilities, StatusResponse.ResponseText));
    }

    private PopCapabilityList capabilities = new PopCapabilityList();
  }
}

==> Smdn.Net.Pop3.Client-1.14.tar.bz2: Smdn.Net.Pop3.Client-1.14/Smdn.Net.Pop3.Client/Smdn.Net.Pop3.Client.Transaction.BuiltIn/CapaTransaction.cs <==
// 
// Author:
//       smdn <smdn@smdn.jp>
// 
// Copyright (c) 2008-2013 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;

using Smdn.Net.Pop3.Protocol.Client;

namespace Smdn.Net.Pop3.Client.Transaction.BuiltIn {
  internal sealed class CapaTransaction : PopTransactionBase<PopCommandResult<PopCapabilitySet>> {
    public CapaTransaction(PopConnection connection)
      : base(connection)
    {
      IsResponseMultiline = true;
    }

    /*
     * RFC 2449 - POP3 Extension Mechanism
     * 
     * CAPA
     *    Arguments:
     *       none
     *    Restrictions:
     *       none
     *    Possible Responses:
     *        +OK -ERR
     */
    protected override PopCommand PrepareCommand()
    {
      return new PopCommand("CAPA");
    }

    protected override void OnFollowingResponseReceived(PopFollowingResponse following)
    {
      capabilities.Add(PopResponseConverter.FromCapa(following));

      base.OnFollowingResponseReceived(following);
    }

    protected override void OnTerminationResponse(PopTerminationResponse termination)
    {
      Finish(new PopCommandResult<PopCapabilitySet>(capabilities, StatusResponse.ResponseText));
    }

    private PopCapabilitySet capabilities = new PopCapabilitySet();
  }
}
